==> php-residence_0.2.4.tar.gz: php-residence/costi.php <==
<html>
<header>
<title> Costi di gestione. </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#################################################################################

$pag = "costi.php";

include ("dati/connessione_db.php");
include ("includes/funzioni.php");
$Euro = nome_valuta();
$tablecosti = costi . $anno;


if ($inserisci_entrata) {

if (!$nome_costo) {
echo mex("Si deve inserire un nome per l' entrata",$pag).".<br>";
$inserire = "NO";
} # fine if (!$nome_costo)

if (!$val_costo) {
echo mex("Si deve inserire il valore dell' entrata",$pag).".<br>";
$inserire = "NO";
} # fine if (!$val_costo)
else {
$val_costo = formatta_soldi($val_costo);
if (controlla_soldi($val_costo) == "NO") {
echo mex("Il valore dell' entrata  sbagliato",$pag).".<br>";
$inserire = "NO";
} # fine if (controlla_soldi($val_costo) == "NO")
} # fine else if (!$val_costo)

if ($inserire != "NO") {
pg_exec("begin");
pg_exec("lock table $tablecosti");
$datainserimento = date("Y-M-d H:i:s");
if ($entrata_da_prenota) {
$provenienza_costo = "p";
$costo0 = pg_exec("select * from $tablecosti where idcosti = 0");
$costo0 = pg_result($costo0,0,val_costo);
$costo0 = $costo0 + $val_costo;
pg_exec("update $tablecosti set val_costo = '$costo0' where idcosti = 0 ");
} # fine if ($entrata_da_prenota)
pg_exec("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,provenienza_costo,tipo_costo,datainserimento,hostinserimento) select max(idcosti)+1,'$nome_costo','$val_costo','$persona_costo','$provenienza_costo','e','$datainserimento','$HOSTNAME' from $tablecosti");
echo mex("L' entrata  stata inserita",$pag).".<br>";
pg_exec("commit");
} # fine if ($inserire != "NO")

echo "<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"OK\">
</form>";
} # fine if ($inserisci_entrata)


else {


if ($inserisci_spesa) {

if (!$nome_costo) {
echo mex("Si deve inserire un nome per la spesa",$pag).".<br>";
$inserire = "NO";
} # fine if (!$nomecosto)

if (!$val_costo) {
echo mex("Si deve inserire il valore della spesa",$pag).".<br>";
$inserire = "NO";
} # fine if (!$val_costo)
else {
$val_costo = formatta_soldi($val_costo);
if (controlla_soldi($val_costo) == "NO") {
echo mex("Il valore della spesa  sbagliato",$pag).".<br>";
$inserire = "NO";
} # fine if (controlla_soldi($val_costo) == "NO")
} # fine else if (!$val_costo)

if ($inserire != "NO") {
pg_exec("begin");
pg_exec("lock table $tablecosti");
$datainserimento = date("Y-M-d H:i:s");
pg_exec("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,tipo_costo,datainserimento,hostinserimento) select max(idcosti)+1,'$nome_costo','$val_costo','$persona_costo','s','$datainserimento','$HOSTNAME' from $tablecosti");
echo mex("La spesa  stata inserita",$pag).".<br>";
pg_exec("commit");
} # fine if ($inserire != "NO")

echo "<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"OK\">
</form>";
} # fine if ($inserisci_spesa)


else {



echo "
<center><font size=+2><b>".mex("Inserisci i costi di gestione per l'anno",$pag)." $anno.</b></font><br>
<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\"><br>
<table cellspacing=2 cellpadding=5>
<tr><td>
".mex("Natura spesa",$pag).":&nbsp;
<input type=\"text\" name=\"nome_costo\" size=\"30\" value=\"\">
</td></tr>
<tr><td>
".mex("Importo",$pag).":&nbsp;
<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$Euro.
</td></tr>
<tr><td>
".mex("Persona che inserisce",$pag).":&nbsp;
<input type=\"text\" name=\"persona_costo\" size=\"20\" value=\"\">&nbsp;(".mex("opzionale",$pag).").
</td></tr></table>
<input type=\"submit\" name=\"inserisci_spesa\" value=\"".mex("Inserisci la spesa",$pag)."\"><br>
</form><hr width=\"95%\">

<font size=+2><b>".mex("Inserisci le entrate in cassa per l'anno",$pag)." $anno.</b></font><br>
<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\"><br>
<table cellspacing=2 cellpadding=5>
<tr><td>
".mex("Natura entrata",$pag).":&nbsp;
<input type=\"text\" name=\"nome_costo\" size=\"30\" value=\"\">
</td></tr>
<tr><td>
".mex("Importo",$pag).":&nbsp;
<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$Euro.
</td></tr>
<tr><td>
".mex("Persona che inserisce",$pag).":&nbsp;
<input type=\"text\" name=\"persona_costo\" size=\"20\" value=\"\">&nbsp;(".mex("opzionale",$pag).").
</td></tr>
<tr><td>
<input type=\"checkbox\" name=\"entrata_da_prenota\" value=\"SI\" checked>
".mex("Sottrai l'importo dal totale delle prenotazioni",$pag).".
</td></tr></table>
<input type=\"submit\" name=\"inserisci_entrata\" value=\"".mex("Inserisci l' entrata",$pag)."\"><br>
</form><hr width=\"95%\">

<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"costi\">
<input type=\"submit\" name=\"visualizza\" value=\"".mex("Visualizza la tabella con tutte le spese e le entrate",$pag)."\">
</form>
<form method=\"post\" action=\"inizio.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"indietro\" value=\"".mex("Torna al men principale",$pag)."\">
</form></center>";


} # fine else if ($inserisci_spesa)

} # fine else if ($inserisci_entrata)



?>

</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/costi.php <==
<html>
<header>
<title> Costi di gestione. </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#################################################################################

$pag = "costi.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
$Euro = nome_valuta();
$tablecosti = costi . $anno;


if ($inserisci_entrata) {

if (!$nome_costo) {
echo mex("Si deve inserire un nome per l' entrata",$pag).".<br>";
$inserire = "NO";
} # fine if (!$nome_costo)

if (!$val_costo) {
echo mex("Si deve inserire il valore dell' entrata",$pag).".<br>";
$inserire = "NO";
} # fine if (!$val_costo)
else {
$val_costo = formatta_soldi($val_costo);
if (controlla_soldi($val_costo) == "NO") {
echo mex("Il valore dell' entrata  sbagliato",$pag).".<br>";
$inserire = "NO";
} # fine if (controlla_soldi($val_costo) == "NO")
} # fine else if (!$val_costo)

if ($inserire != "NO") {
$tabelle_lock = array("$tablecosti");
$tabelle_lock = lock_tabelle($tabelle_lock);
$datainserimento = date("Y-m-d H:i:s");
if ($entrata_da_prenota) {
$provenienza_costo = "p";
$costo0 = esegui_query("select * from $tablecosti where idcosti = 0");
$costo0 = risul_query($costo0,0,val_costo);
$costo0 = $costo0 + $val_costo;
esegui_query("update $tablecosti set val_costo = '$costo0' where idcosti = 0 ");
} # fine if ($entrata_da_prenota)
$idcosti = esegui_query("select max(idcosti) from $tablecosti");
$idcosti = risul_query($idcosti,0,0) + 1;
esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,provenienza_costo,tipo_costo,datainserimento,hostinserimento) values ('$idcosti','$nome_costo','$val_costo','$persona_costo','$provenienza_costo','e','$datainserimento','$HOSTNAME') ");
echo mex("L' entrata  stata inserita",$pag).".<br>";
unlock_tabelle($tabelle_lock);
} # fine if ($inserire != "NO")

echo "<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"OK\">
</form>";
} # fine if ($inserisci_entrata)


else {


if ($inserisci_spesa) {

if (!$nome_costo) {
echo mex("Si deve inserire un nome per la spesa",$pag).".<br>";
$inserire = "NO";
} # fine if (!$nomecosto)

if (!$val_costo) {
echo mex("Si deve inserire il valore della spesa",$pag).".<br>";
$inserire = "NO";
} # fine if (!$val_costo)
else {
$val_costo = formatta_soldi($val_costo);
if (controlla_soldi($val_costo) == "NO") {
echo mex("Il valore della spesa  sbagliato",$pag).".<br>";
$inserire = "NO";
} # fine if (controlla_soldi($val_costo) == "NO")
} # fine else if (!$val_costo)

if ($inserire != "NO") {
$tabelle_lock = array("$tablecosti");
$tabelle_lock = lock_tabelle($tabelle_lock);
$datainserimento = date("Y-m-d H:i:s");
$idcosti = esegui_query("select max(idcosti) from $tablecosti");
$idcosti = risul_query($idcosti,0,0) + 1;
esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,tipo_costo,datainserimento,hostinserimento) values ('$idcosti','$nome_costo','$val_costo','$persona_costo','s','$datainserimento','$HOSTNAME') ");
echo mex("La spesa  stata inserita",$pag).".<br>";
unlock_tabelle($tabelle_lock);
} # fine if ($inserire != "NO")

echo "<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"OK\">
</form>";
} # fine if ($inserisci_spesa)


else {



echo "
<center><font size=+2><b>".mex("Inserisci i costi di gestione per l'anno",$pag)." $anno.</b></font><br>
<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\"><br>
<table cellspacing=2 cellpadding=5>
<tr><td>
".mex("Natura spesa",$pag).":&nbsp;
<input type=\"text\" name=\"nome_costo\" size=\"30\" value=\"\">
</td></tr>
<tr><td>
".mex("Importo",$pag).":&nbsp;
<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$Euro.
</td></tr>
<tr><td>
".mex("Persona che inserisce",$pag).":&nbsp;
<input type=\"text\" name=\"persona_costo\" size=\"20\" value=\"\">&nbsp;(".mex("opzionale",$pag).").
</td></tr></table>
<input type=\"submit\" name=\"inserisci_spesa\" value=\"".mex("Inserisci la spesa",$pag)."\"><br>
</form><hr width=\"95%\">

<font size=+2><b>".mex("Inserisci le entrate in cassa per l'anno",$pag)." $anno.</b></font><br>
<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\"><br>
<table cellspacing=2 cellpadding=5>
<tr><td>
".mex("Natura entrata",$pag).":&nbsp;
<input type=\"text\" name=\"nome_costo\" size=\"30\" value=\"\">
</td></tr>
<tr><td>
".mex("Importo",$pag).":&nbsp;
<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$Euro.
</td></tr>
<tr><td>
".mex("Persona che inserisce",$pag).":&nbsp;
<input type=\"text\" name=\"persona_costo\" size=\"20\" value=\"\">&nbsp;(".mex("opzionale",$pag).").
</td></tr>
<tr><td>
<input type=\"checkbox\" name=\"entrata_da_prenota\" value=\"SI\" checked>
".mex("Sottrai l'importo dal totale delle prenotazioni",$pag).".
</td></tr></table>
<input type=\"submit\" name=\"inserisci_entrata\" value=\"".mex("Inserisci l' entrata",$pag)."\"><br>
</form><hr width=\"95%\">

<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"costi\">
<input type=\"submit\" name=\"visualizza\" value=\"".mex("Visualizza la tabella con tutte le spese e le entrate",$pag)."\">
</form>
<form method=\"post\" action=\"inizio.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"indietro\" value=\"".mex("Torna al men principale",$pag)."\">
</form></center>";


} # fine else if ($inserisci_spesa)

} # fine else if ($inserisci_entrata)



?>

</body>
</html>
